@@ -201,6 +201,10 @@ class Product(BaseModel):
     stock_type: Optional[Literal["always", "period", "total"]] = "always"
     stock_amount: Optional[int] = 0
     stock_sold_amount: Optional[int] = 0
+    stock_start_date: Optional[str]
+    stock_start_time: Optional[str]
+    stock_end_date: Optional[str]
+    stock_end_time: Optional[str]
     variants: List[Union[SingleVariant, BooleanVariant]] = []
     on_shelf: Optional[bool]
     public: Optional[bool]
