@@ -1,3 +1,5 @@
+from typing import Any, Dict, Union
+
 from pymongo.collection import Collection
 
 product_collection: Collection = None
@@ -7,6 +9,7 @@ user_collection: Collection = None
 user_profile_collection: Collection = None
 private_profile_collection: Collection = None
 cart_collection: Collection = None
+site_collection: Collection = None
 
 
 def set_collections(
@@ -17,6 +20,7 @@ def set_collections(
     user_profile: Collection,
     private_profile: Collection,
     cart: Collection,
+    site: Collection,
 ) -> None:
     global product_collection
     global coupon_collection
@@ -25,6 +29,7 @@ def set_collections(
     global user_profile_collection
     global private_profile_collection
     global cart_collection
+    global site_collection
     product_collection = product
     coupon_collection = coupon
     discount_collection = discount
@@ -32,6 +37,7 @@ def set_collections(
     user_profile_collection = user_profile
     private_profile_collection = private_profile
     cart_collection = cart
+    site_collection = site
 
 
 def get_collection(name: str) -> Collection:
@@ -49,3 +55,18 @@ def get_collection(name: str) -> Collection:
         return user_profile_collection
     if name == "private_profile":
         return private_profile_collection
+    if name == "site":
+        return site_collection
+
+
+def get_site_config_doc() -> Union[Dict[str, Any], None]:
+    if site_collection is None:
+        return None
+    return site_collection.find_one({"name": "config"})  # type: ignore
+
+
+def get_site_config(key: str, default: Any = None) -> Any:
+    config_doc = get_site_config_doc()
+    if config_doc is None:
+        return default
+    return config_doc.get(key, default)
