@@ -13,7 +13,8 @@ def log_all(action: str) -> WrapT:
         def wrapper(*args: Any, **kwargs: Any) -> Any:
             url: str = args[0]
             json = kwargs.get("json", None)
-            print("[REQ]", action, url, json)
+            data = kwargs.get("data", None)
+            print("[REQ]", action, url, f"json={json}", f"data={data}")
             return fn(*args, **kwargs)
 
         return cast(FuncT, wrapper)
